@@ -115,16 +115,10 @@ const userRequestsFilterCheckbox = `
 
 export function initOriginSave() {
 
-  $(document).ready(async() => {
+  $(document).ready(() => {
 
     $.fn.dataTable.ext.errMode = 'none';
 
-    const response = await fetch(Urls.origin_save_types_list());
-    const data = await response.json();
-
-    for (const originType of data) {
-      $('#swh-input-visit-type').append(`<option value="${originType}">${originType}</option>`);
-    }
     // set git as the default value as before
     $('#swh-input-visit-type').val('git');
 
@@ -212,10 +206,11 @@ export function initOriginSave() {
           {
             name: 'info',
             render: (data, type, row) => {
-              if (row.save_task_status === 'succeeded' || row.save_task_status === 'failed') {
-                return `<i class="mdi mdi-information-outline swh-save-request-info" ` +
-                       'aria-hidden="true" style="cursor: pointer"' +
-                       `onclick="swh.save.displaySaveRequestInfo(event, ${row.id})"></i>`;
+              if (row.save_task_status === 'succeeded' || row.save_task_status === 'failed' ||
+                  row.note != null) {
+                return `<i class="mdi mdi-information-outline swh-save-request-info"
+                           aria-hidden="true" style="cursor: pointer"
+                           onclick="swh.save.displaySaveRequestInfo(event, ${row.id})"></i>`;
               } else {
                 return '';
               }
@@ -364,33 +359,14 @@ export function validateSaveOriginUrl(input) {
   }
 
   if (validUrl) {
-    const allowedProtocols = ['http:', 'https:', 'svn:', 'git:'];
+    const allowedProtocols = ['http:', 'https:', 'svn:', 'git:', 'rsync:', 'pserver:', 'ssh:'];
     validUrl = (
       allowedProtocols.find(protocol => protocol === originUrl.protocol) !== undefined
     );
   }
 
   if (validUrl && originType === 'git') {
-    // additional checks for well known code hosting providers
-    switch (originUrl.hostname) {
-      case 'github.com':
-        validUrl = isGitRepoUrl(originUrl);
-        break;
-
-      case 'git.code.sf.net':
-        validUrl = isGitRepoUrl(originUrl, '/p/');
-        break;
-
-      case 'bitbucket.org':
-        validUrl = isGitRepoUrl(originUrl);
-        break;
-
-      default:
-        if (originUrl.hostname.startsWith('gitlab.')) {
-          validUrl = isGitRepoUrl(originUrl);
-        }
-        break;
-    }
+    validUrl = isGitRepoUrl(originUrl);
   }
 
   if (validUrl) {
@@ -506,6 +482,9 @@ export async function displaySaveRequestInfo(event, saveRequestId) {
   let content;
   if ($.isEmptyObject(saveRequestTaskInfo)) {
     content = 'Not available';
+
+  } else if (saveRequestTaskInfo.note != null) {
+    content = saveRequestTaskInfo.note;
   } else {
     const saveRequestInfo = [];
     const taskData = {
