@@ -20,15 +20,15 @@ describe('Test top-bar', function() {
       .and('have.attr', 'href');
   });
 
-  it('should show donate button on lg screen', function() {
-    cy.get('.swh-donate-link')
-      .should('be.visible');
-  });
-  it('should hide donate button on sm screen', function() {
-    cy.viewport(600, 800);
-    cy.get('.swh-donate-link')
-      .should('not.be.visible');
-  });
+  // it('should show donate button on lg screen', function() {
+  //   cy.get('.swh-donate-link')
+  //     .should('be.visible');
+  // });
+  // it('should hide donate button on sm screen', function() {
+  //   cy.viewport(600, 800);
+  //   cy.get('.swh-donate-link')
+  //     .should('not.be.visible');
+  // });
   it('should hide full width switch on small screens', function() {
     cy.viewport(360, 740);
     cy.get('#swh-full-width-switch-container')
@@ -163,10 +163,10 @@ describe('Test top-bar', function() {
     ];
 
     for (let i = 0; i < statusTestData.length; ++i) {
-      cy.visit(url);
       cy.intercept(`${statusUrl}/**`, {
         body: genStatusResponse(statusTestData[i].status, statusTestData[i].statusCode)
       }).as(`getSwhStatusData`);
+      cy.visit(url);
       cy.wait(`@getSwhStatusData`);
       cy.get('.swh-current-status-indicator').should('have.class', statusTestData[i].color);
       cy.get('#swh-current-status-description').should('have.text', statusTestData[i].status);
