@@ -19,8 +19,8 @@ const saveCodeMsg = {
   'csrfError': 'CSRF Failed: Referrer checking failed - no Referrer.'
 };
 
-const anonymousVisitTypes = ['git', 'hg', 'svn'];
-const allVisitTypes = ['archives', 'git', 'hg', 'svn'];
+const anonymousVisitTypes = ['cvs', 'git', 'hg', 'svn'];
+const allVisitTypes = ['archives', 'cvs', 'git', 'hg', 'svn'];
 
 function makeOriginSaveRequest(originType, originUrl) {
   cy.get('#swh-input-origin-url')
@@ -174,6 +174,22 @@ describe('Origin Save Tests', function() {
     });
   });
 
+  it('should validate git repo url starting with https://git.code.sf.net/u/', function() {
+    const sfUserGirProjectUrl = 'https://git.code.sf.net/u/username/project.git';
+    const originSaveUrl = this.Urls.api_1_save_origin('git', sfUserGirProjectUrl);
+
+    stubSaveRequest({requestUrl: originSaveUrl,
+                     saveRequestStatus: 'accepted',
+                     originurl: sfUserGirProjectUrl,
+                     saveTaskStatus: 'not yet scheduled'});
+
+    makeOriginSaveRequest('git', sfUserGirProjectUrl);
+
+    cy.wait('@saveRequest').then(() => {
+      checkAlertVisible('success', saveCodeMsg['success']);
+    });
+  });
+
   it('should display warning message when pending', function() {
     stubSaveRequest({requestUrl: this.originSaveUrl,
                      saveRequestStatus: 'pending',
