@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,7 +6,6 @@
 import base64
 import stat
 import textwrap
-from threading import Lock
 
 import magic
 import sentry_sdk
@@ -68,9 +67,6 @@ def get_directory_entries(sha1_git):
     return dirs, files
 
 
-_lock = Lock()
-
-
 def get_mimetype_and_encoding_for_content(content):
     """Function that returns the mime type and the encoding associated to
     a content buffer using the magic module under the hood.
@@ -161,11 +157,6 @@ def request_content(
     if filetype:
         mimetype = filetype["mimetype"]
         encoding = filetype["encoding"]
-        # workaround when encountering corrupted data due to implicit
-        # conversion from bytea to text in the indexer db (see T818)
-        # TODO: Remove that code when all data have been correctly converted
-        if mimetype.startswith("\\"):
-            filetype = None
 
     if not max_size or content_data["length"] < max_size:
         try:
@@ -234,8 +225,6 @@ def prepare_content_for_display(content_data, mime_type, path):
 
     if not language:
         language = "nohighlight"
-    elif mime_type.startswith("application/"):
-        mime_type = mime_type.replace("application/", "text/")
 
     if mime_type.startswith("image/"):
         if mime_type in browsers_supported_image_mimes:
@@ -244,7 +233,7 @@ def prepare_content_for_display(content_data, mime_type, path):
     if mime_type.startswith("image/svg"):
         mime_type = "image/svg+xml"
 
-    if mime_type.startswith("text/"):
+    if mime_type.startswith("text/") or mime_type.startswith("application/"):
         content_data = content_data.decode("utf-8", errors="replace")
 
     return {"content_data": content_data, "language": language, "mimetype": mime_type}
