@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2020  The Software Heritage developers
+# Copyright (C) 2018-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,28 +6,17 @@
 import random
 from urllib.parse import quote
 
-from hypothesis import given
-
-from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT
 from swh.model.model import Origin
+from swh.model.swhids import ObjectType
 from swh.web.common.identifiers import gen_swhid
 from swh.web.common.utils import reverse
 from swh.web.tests.django_asserts import assert_contains
-from swh.web.tests.strategies import (
-    content,
-    directory,
-    origin,
-    release,
-    revision,
-    snapshot,
-)
 from swh.web.tests.utils import check_html_get_response
 
 
-@given(content())
 def test_content_id_browse(client, content):
     cnt_sha1_git = content["sha1_git"]
-    swhid = gen_swhid(CONTENT, cnt_sha1_git)
+    swhid = gen_swhid(ObjectType.CONTENT, cnt_sha1_git)
 
     for swhid_ in (swhid, swhid.upper()):
         url = reverse("browse-swhid", url_args={"swhid": swhid_})
@@ -41,9 +30,8 @@ def test_content_id_browse(client, content):
         assert resp["location"] == content_browse_url
 
 
-@given(directory())
 def test_directory_id_browse(client, directory):
-    swhid = gen_swhid(DIRECTORY, directory)
+    swhid = gen_swhid(ObjectType.DIRECTORY, directory)
 
     for swhid_ in (swhid, swhid.upper()):
         url = reverse("browse-swhid", url_args={"swhid": swhid_})
@@ -56,9 +44,8 @@ def test_directory_id_browse(client, directory):
         assert resp["location"] == directory_browse_url
 
 
-@given(revision())
 def test_revision_id_browse(client, revision):
-    swhid = gen_swhid(REVISION, revision)
+    swhid = gen_swhid(ObjectType.REVISION, revision)
 
     for swhid_ in (swhid, swhid.upper()):
         url = reverse("browse-swhid", url_args={"swhid": swhid_})
@@ -85,9 +72,8 @@ def test_revision_id_browse(client, revision):
         assert resp["location"] == revision_browse_url
 
 
-@given(release())
 def test_release_id_browse(client, release):
-    swhid = gen_swhid(RELEASE, release)
+    swhid = gen_swhid(ObjectType.RELEASE, release)
 
     for swhid_ in (swhid, swhid.upper()):
         url = reverse("browse-swhid", url_args={"swhid": swhid_})
@@ -111,9 +97,8 @@ def test_release_id_browse(client, release):
         assert resp["location"] == release_browse_url
 
 
-@given(snapshot())
 def test_snapshot_id_browse(client, snapshot):
-    swhid = gen_swhid(SNAPSHOT, snapshot)
+    swhid = gen_swhid(ObjectType.SNAPSHOT, snapshot)
 
     for swhid_ in (swhid, swhid.upper()):
         url = reverse("browse-swhid", url_args={"swhid": swhid_})
@@ -141,7 +126,6 @@ def test_snapshot_id_browse(client, snapshot):
         assert resp["location"] == release_browse_url
 
 
-@given(release())
 def test_bad_id_browse(client, release):
     swhid = f"swh:1:foo:{release}"
     url = reverse("browse-swhid", url_args={"swhid": swhid})
@@ -149,7 +133,6 @@ def test_bad_id_browse(client, release):
     check_html_get_response(client, url, status_code=400)
 
 
-@given(content())
 def test_content_id_optional_parts_browse(client, archive_data, content):
     cnt_sha1_git = content["sha1_git"]
     origin_url = "https://github.com/user/repo"
@@ -157,7 +140,9 @@ def test_content_id_optional_parts_browse(client, archive_data, content):
     archive_data.origin_add([Origin(url=origin_url)])
 
     swhid = gen_swhid(
-        CONTENT, cnt_sha1_git, metadata={"lines": "4-20", "origin": origin_url},
+        ObjectType.CONTENT,
+        cnt_sha1_git,
+        metadata={"lines": "4-20", "origin": origin_url},
     )
     url = reverse("browse-swhid", url_args={"swhid": swhid})
 
@@ -173,7 +158,6 @@ def test_content_id_optional_parts_browse(client, archive_data, content):
     assert resp["location"] == content_browse_url
 
 
-@given(release())
 def test_origin_id_not_resolvable(client, release):
     swhid = "swh:1:ori:8068d0075010b590762c6cb5682ed53cb3c13deb"
     url = reverse("browse-swhid", url_args={"swhid": swhid})
@@ -181,7 +165,6 @@ def test_origin_id_not_resolvable(client, release):
     check_html_get_response(client, url, status_code=400)
 
 
-@given(origin())
 def test_legacy_swhid_browse(archive_data, client, origin):
     snapshot = archive_data.snapshot_get_latest(origin["url"])
     revision = archive_data.snapshot_get_head(snapshot)
@@ -191,7 +174,7 @@ def test_legacy_swhid_browse(archive_data, client, origin):
         [e for e in directory_content if e["type"] == "file"]
     )
     legacy_swhid = gen_swhid(
-        CONTENT,
+        ObjectType.CONTENT,
         directory_file["checksums"]["sha1_git"],
         metadata={"origin": origin["url"]},
     )
@@ -204,12 +187,12 @@ def test_legacy_swhid_browse(archive_data, client, origin):
     )
 
     swhid = gen_swhid(
-        CONTENT,
+        ObjectType.CONTENT,
         directory_file["checksums"]["sha1_git"],
         metadata={
             "origin": origin["url"],
-            "visit": gen_swhid(SNAPSHOT, snapshot["id"]),
-            "anchor": gen_swhid(REVISION, revision),
+            "visit": gen_swhid(ObjectType.SNAPSHOT, snapshot["id"]),
+            "anchor": gen_swhid(ObjectType.REVISION, revision),
         },
     )
 
@@ -226,13 +209,14 @@ def test_legacy_swhid_browse(archive_data, client, origin):
     assert_contains(resp, swhid)
 
 
-@given(directory())
 def test_browse_swhid_special_characters_escaping(client, archive_data, directory):
     origin = "http://example.org/?project=abc;"
     archive_data.origin_add([Origin(url=origin)])
     origin_swhid_escaped = quote(origin, safe="/?:@&")
     origin_swhid_url_escaped = quote(origin, safe="/:@;")
-    swhid = gen_swhid(DIRECTORY, directory, metadata={"origin": origin_swhid_escaped})
+    swhid = gen_swhid(
+        ObjectType.DIRECTORY, directory, metadata={"origin": origin_swhid_escaped}
+    )
     url = reverse("browse-swhid", url_args={"swhid": swhid})
 
     resp = check_html_get_response(client, url, status_code=302)
