@@ -5,7 +5,6 @@
 
 import random
 import re
-import string
 
 from hypothesis import given
 import pytest
@@ -25,13 +24,7 @@ from swh.storage.utils import now
 from swh.web.browse.snapshot_context import process_snapshot_branches
 from swh.web.common.exc import NotFoundExc
 from swh.web.common.identifiers import gen_swhid
-from swh.web.common.utils import (
-    format_utc_iso_date,
-    gen_path_info,
-    parse_iso8601_date_to_utc,
-    reverse,
-)
-from swh.web.tests.data import get_content, random_sha1
+from swh.web.common.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
 from swh.web.tests.django_asserts import assert_contains, assert_not_contains
 from swh.web.tests.strategies import new_origin, new_snapshot, visit_dates
 from swh.web.tests.utils import check_html_get_response
@@ -58,97 +51,6 @@ def test_origin_visits_browse(client, archive_data, origin_with_multiple_visits)
     _check_origin_link(resp, origin_url)
 
 
-def test_origin_content_view(
-    client, archive_data, swh_scheduler, origin_with_multiple_visits
-):
-    origin_visits = archive_data.origin_visit_get(origin_with_multiple_visits["url"])
-
-    def _get_archive_data(visit_idx):
-        snapshot = archive_data.snapshot_get(origin_visits[visit_idx]["snapshot"])
-        head_rev_id = archive_data.snapshot_get_head(snapshot)
-        head_rev = archive_data.revision_get(head_rev_id)
-        dir_content = archive_data.directory_ls(head_rev["directory"])
-        dir_files = [e for e in dir_content if e["type"] == "file"]
-        dir_file = random.choice(dir_files)
-        branches, releases, _ = process_snapshot_branches(snapshot)
-        return {
-            "branches": branches,
-            "releases": releases,
-            "root_dir_sha1": head_rev["directory"],
-            "content": get_content(dir_file["checksums"]["sha1"]),
-            "visit": origin_visits[visit_idx],
-            "snapshot_sizes": archive_data.snapshot_count_branches(snapshot["id"]),
-        }
-
-    tdata = _get_archive_data(-1)
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin_with_multiple_visits,
-        origin_visits[-1],
-        tdata["snapshot_sizes"],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-    )
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin_with_multiple_visits,
-        origin_visits[-1],
-        tdata["snapshot_sizes"],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-        timestamp=tdata["visit"]["date"],
-    )
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin_with_multiple_visits,
-        origin_visits[-1],
-        tdata["snapshot_sizes"],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-        snapshot_id=tdata["visit"]["snapshot"],
-    )
-
-    tdata = _get_archive_data(0)
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin_with_multiple_visits,
-        origin_visits[0],
-        tdata["snapshot_sizes"],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-        visit_id=tdata["visit"]["visit"],
-    )
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin_with_multiple_visits,
-        origin_visits[0],
-        tdata["snapshot_sizes"],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-        snapshot_id=tdata["visit"]["snapshot"],
-    )
-
-
 def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
@@ -396,36 +298,6 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
     )
 
 
-def test_origin_branches(client, archive_data, origin):
-    origin_visits = archive_data.origin_visit_get(origin["url"])
-
-    visit = origin_visits[-1]
-    snapshot = archive_data.snapshot_get(visit["snapshot"])
-    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
-    snapshot_content = process_snapshot_branches(snapshot)
-
-    _origin_branches_test_helper(client, origin, snapshot_content, snapshot_sizes)
-
-    _origin_branches_test_helper(
-        client, origin, snapshot_content, snapshot_sizes, snapshot_id=visit["snapshot"]
-    )
-
-
-def test_origin_releases(client, archive_data, origin):
-    origin_visits = archive_data.origin_visit_get(origin["url"])
-
-    visit = origin_visits[-1]
-    snapshot = archive_data.snapshot_get(visit["snapshot"])
-    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
-    snapshot_content = process_snapshot_branches(snapshot)
-
-    _origin_releases_test_helper(client, origin, snapshot_content, snapshot_sizes)
-
-    _origin_releases_test_helper(
-        client, origin, snapshot_content, snapshot_sizes, snapshot_id=visit["snapshot"]
-    )
-
-
 @given(
     new_origin(), new_snapshot(min_size=4, max_size=4), visit_dates(),
 )
@@ -560,43 +432,6 @@ def test_browse_origin_directory_not_found(client, origin):
     assert re.search("Directory.*not found", resp.content.decode("utf-8"))
 
 
-def test_browse_origin_content_no_visit(client, mocker, origin):
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_visits.get_origin_visits"
-    )
-    mock_get_origin_visits.return_value = []
-    mock_archive = mocker.patch("swh.web.common.origin_visits.archive")
-    mock_archive.lookup_origin_visit_latest.return_value = None
-    url = reverse(
-        "browse-origin-content",
-        query_params={"origin_url": origin["url"], "path": "foo"},
-    )
-
-    resp = check_html_get_response(
-        client, url, status_code=404, template_used="error.html"
-    )
-    assert_contains(resp, "No valid visit", status_code=404)
-    assert not mock_get_origin_visits.called
-
-
-def test_browse_origin_content_unknown_visit(client, mocker, origin):
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_visits.get_origin_visits"
-    )
-    mock_get_origin_visits.return_value = [{"visit": 1}]
-
-    url = reverse(
-        "browse-origin-content",
-        query_params={"origin_url": origin["url"], "path": "foo", "visit_id": 2},
-    )
-
-    resp = check_html_get_response(
-        client, url, status_code=404, template_used="error.html"
-    )
-    assert re.search("Visit.*not found", resp.content.decode("utf-8"))
-    assert mock_get_origin_visits.called
-
-
 def _add_empty_snapshot_origin(new_origin, archive_data):
     snapshot = Snapshot(branches={})
     archive_data.origin_add([new_origin])
@@ -615,7 +450,7 @@ def _add_empty_snapshot_origin(new_origin, archive_data):
 
 
 @pytest.mark.django_db
-@pytest.mark.parametrize("object_type", ["content", "directory"])
+@pytest.mark.parametrize("object_type", ["directory"])
 @given(new_origin())
 def test_browse_origin_content_directory_empty_snapshot(
     client, staff_user, archive_data, object_type, new_origin
@@ -637,18 +472,6 @@ def test_browse_origin_content_directory_empty_snapshot(
     assert re.search("snapshot.*is empty", resp.content.decode("utf-8"))
 
 
-def test_browse_origin_content_not_found(client, origin):
-    url = reverse(
-        "browse-origin-content",
-        query_params={"origin_url": origin["url"], "path": "/invalid/file/path"},
-    )
-
-    resp = check_html_get_response(
-        client, url, status_code=404, template_used="browse/content.html"
-    )
-    assert re.search("Directory entry.*not found", resp.content.decode("utf-8"))
-
-
 def test_browse_directory_snapshot_not_found(client, mocker, origin):
     mock_get_snapshot_context = mocker.patch(
         "swh.web.browse.snapshot_context.get_snapshot_context"
@@ -817,23 +640,9 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
     assert_not_contains(resp, "swh:1:rev:")
 
 
-def test_origin_content_no_path(client, origin):
-    url = reverse("browse-origin-content", query_params={"origin_url": origin["url"]})
-
-    resp = check_html_get_response(
-        client, url, status_code=400, template_used="error.html"
-    )
-    assert_contains(
-        resp, "The path of a content must be given as query parameter.", status_code=400
-    )
-
-
 def test_origin_views_no_url_query_parameter(client):
     for browse_context in (
-        "content",
         "directory",
-        "branches",
-        "releases",
         "visits",
     ):
         url = reverse(f"browse-origin-{browse_context}")
@@ -846,7 +655,7 @@ def test_origin_views_no_url_query_parameter(client):
 
 
 @given(new_origin())
-@pytest.mark.parametrize("browse_context", ["log"])
+@pytest.mark.parametrize("browse_context", ["log", "branches", "releases"])
 def test_origin_view_redirects(client, browse_context, new_origin):
     query_params = {"origin_url": new_origin.url}
     url = reverse(f"browse-origin-{browse_context}", query_params=query_params)
@@ -858,159 +667,60 @@ def test_origin_view_redirects(client, browse_context, new_origin):
 
 
 @given(new_origin())
-@pytest.mark.parametrize("browse_context", ["log"])
-def test_origin_view_legacy_redirects(client, browse_context, new_origin):
-    params = {"origin_url": new_origin.url, "timestamp": "2021-01-23T22:24:10Z"}
-    url = reverse(
-        f"browse-origin-{browse_context}-legacy", url_args=params, query_params=params
-    )
+@pytest.mark.parametrize("browse_context", ["content"])
+def test_origin_content_view_redirects(client, browse_context, new_origin):
+    query_params = {"origin_url": new_origin.url, "path": "test.txt"}
+    url = reverse(f"browse-origin-{browse_context}", query_params=query_params)
 
     resp = check_html_get_response(client, url, status_code=301)
     assert resp["location"] == reverse(
-        f"browse-snapshot-{browse_context}", query_params=params
+        f"browse-{browse_context}", query_params=query_params
     )
 
 
-def _origin_content_view_test_helper(
-    client,
-    archive_data,
-    origin_info,
-    origin_visit,
-    snapshot_sizes,
-    origin_branches,
-    origin_releases,
-    root_dir_sha1,
-    content,
-    visit_id=None,
-    timestamp=None,
-    snapshot_id=None,
-):
-    content_path = "/".join(content["path"].split("/")[1:])
-
-    if not visit_id and not snapshot_id:
-        visit_id = origin_visit["visit"]
-
-    query_params = {"origin_url": origin_info["url"], "path": content_path}
-
-    if timestamp:
-        query_params["timestamp"] = timestamp
-
-    if visit_id:
-        query_params["visit_id"] = visit_id
-    elif snapshot_id:
-        query_params["snapshot"] = snapshot_id
-
-    url = reverse("browse-origin-content", query_params=query_params)
-
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/content.html"
-    )
-
-    assert type(content["data"]) == str
-
-    assert_contains(resp, '<code class="%s">' % content["hljs_language"])
-    assert_contains(resp, escape(content["data"]))
-
-    split_path = content_path.split("/")
-
-    filename = split_path[-1]
-    path = content_path.replace(filename, "")[:-1]
-
-    path_info = gen_path_info(path)
-
-    del query_params["path"]
-
-    if timestamp:
-        query_params["timestamp"] = format_utc_iso_date(
-            parse_iso8601_date_to_utc(timestamp).isoformat(), "%Y-%m-%dT%H:%M:%SZ"
+@given(new_origin())
+@pytest.mark.parametrize("browse_context", ["log", "branches", "releases"])
+def test_origin_view_legacy_redirects(client, browse_context, new_origin):
+    # Each legacy route corresponds to two URL patterns, testing both
+    url_args = [
+        {"origin_url": new_origin.url},
+        {"origin_url": new_origin.url, "timestamp": "2021-01-23T22:24:10Z"},
+    ]
+    params = {"extra-param1": "extra-param1", "extra-param2": "extra-param2"}
+    for each_arg in url_args:
+        url = reverse(
+            f"browse-origin-{browse_context}-legacy",
+            url_args=each_arg,
+            query_params=params,
         )
 
-    root_dir_url = reverse("browse-origin-directory", query_params=query_params)
-
-    assert_contains(resp, '<li class="swh-path">', count=len(path_info) + 1)
-
-    assert_contains(resp, '<a href="%s">%s</a>' % (root_dir_url, root_dir_sha1[:7]))
-
-    for p in path_info:
-        query_params["path"] = p["path"]
-        dir_url = reverse("browse-origin-directory", query_params=query_params)
-        assert_contains(resp, '<a href="%s">%s</a>' % (dir_url, p["name"]))
-
-    assert_contains(resp, "<li>%s</li>" % filename)
-
-    query_string = "sha1_git:" + content["sha1_git"]
-
-    url_raw = reverse(
-        "browse-content-raw",
-        url_args={"query_string": query_string},
-        query_params={"filename": filename},
-    )
-    assert_contains(resp, url_raw)
-
-    if "path" in query_params:
-        del query_params["path"]
-
-    origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
-
-    assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
-
-    origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
-
-    assert_contains(resp, f'href="{escape(origin_releases_url)}">')
-    assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
-
-    assert_contains(resp, '<li class="swh-branch">', count=len(origin_branches))
-
-    query_params["path"] = content_path
-
-    for branch in origin_branches:
-        root_dir_branch_url = reverse(
-            "browse-origin-content",
-            query_params={"branch": branch["name"], **query_params},
+        resp = check_html_get_response(client, url, status_code=301)
+        assert resp["location"] == reverse(
+            f"browse-snapshot-{browse_context}", query_params={**each_arg, **params}
         )
 
-        assert_contains(resp, '<a href="%s">' % root_dir_branch_url)
 
-    assert_contains(resp, '<li class="swh-release">', count=len(origin_releases))
-
-    query_params["branch"] = None
-    for release in origin_releases:
-        root_dir_release_url = reverse(
-            "browse-origin-content",
-            query_params={"release": release["name"], **query_params},
+@given(new_origin())
+def test_origin_content_view_legacy_redirects(client, new_origin):
+    url_args = [
+        {"origin_url": new_origin.url},
+        {
+            "origin_url": new_origin.url,
+            "path": "test.txt",
+            "timestamp": "2021-01-23T22:24:10Z",
+        },
+        {"origin_url": new_origin.url, "path": "test.txt"},
+    ]
+    params = {"extra-param1": "extra-param1", "extra-param2": "extra-param2"}
+    for each_arg in url_args:
+        url = reverse(
+            "browse-origin-content-legacy", url_args=each_arg, query_params=params,
         )
 
-        assert_contains(resp, '<a href="%s">' % root_dir_release_url)
-
-    url = reverse("browse-origin-content", query_params=query_params)
-
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/content.html"
-    )
-
-    snapshot = archive_data.snapshot_get(origin_visit["snapshot"])
-    head_rev_id = archive_data.snapshot_get_head(snapshot)
-
-    swhid_context = {
-        "origin": origin_info["url"],
-        "visit": gen_swhid(ObjectType.SNAPSHOT, snapshot["id"]),
-        "anchor": gen_swhid(ObjectType.REVISION, head_rev_id),
-        "path": f"/{content_path}",
-    }
-
-    swh_cnt_id = gen_swhid(
-        ObjectType.CONTENT, content["sha1_git"], metadata=swhid_context
-    )
-    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
-    assert_contains(resp, swh_cnt_id)
-    assert_contains(resp, swh_cnt_id_url)
-
-    assert_contains(resp, "swh-take-new-snapshot")
-
-    _check_origin_link(resp, origin_info["url"])
-
-    assert_not_contains(resp, "swh-metadata-popover")
+        resp = check_html_get_response(client, url, status_code=301)
+        assert resp["location"] == reverse(
+            "browse-content", query_params={**each_arg, **params}
+        )
 
 
 def _origin_directory_view_test_helper(
@@ -1155,147 +865,6 @@ def _origin_directory_view_test_helper(
     assert_not_contains(resp, "swh-metadata-popover")
 
 
-def _origin_branches_test_helper(
-    client, origin_info, origin_snapshot, snapshot_sizes, snapshot_id=None
-):
-    query_params = {"origin_url": origin_info["url"], "snapshot": snapshot_id}
-
-    url = reverse("browse-origin-branches", query_params=query_params)
-
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/branches.html"
-    )
-
-    origin_branches = origin_snapshot[0]
-    origin_releases = origin_snapshot[1]
-
-    origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
-
-    assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
-
-    origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
-
-    nb_releases = len(origin_releases)
-    if nb_releases > 0:
-        assert_contains(resp, f'href="{escape(origin_releases_url)}">')
-        assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
-
-    assert_contains(resp, '<tr class="swh-branch-entry', count=len(origin_branches))
-
-    for branch in origin_branches:
-        browse_branch_url = reverse(
-            "browse-origin-directory",
-            query_params={"branch": branch["name"], **query_params},
-        )
-        assert_contains(resp, '<a href="%s">' % escape(browse_branch_url))
-
-        browse_revision_url = reverse(
-            "browse-revision",
-            url_args={"sha1_git": branch["revision"]},
-            query_params=query_params,
-        )
-        assert_contains(resp, '<a href="%s">' % escape(browse_revision_url))
-
-    _check_origin_link(resp, origin_info["url"])
-
-
-def _origin_releases_test_helper(
-    client, origin_info, origin_snapshot, snapshot_sizes, snapshot_id=None
-):
-    query_params = {"origin_url": origin_info["url"], "snapshot": snapshot_id}
-
-    url = reverse("browse-origin-releases", query_params=query_params)
-
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/releases.html"
-    )
-
-    origin_releases = origin_snapshot[1]
-
-    origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
-
-    assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
-
-    origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
-
-    nb_releases = len(origin_releases)
-    if nb_releases > 0:
-        assert_contains(resp, f'href="{escape(origin_releases_url)}"')
-        assert_contains(resp, f"Releases ({snapshot_sizes['release']}")
-
-    assert_contains(resp, '<tr class="swh-release-entry', count=nb_releases)
-    assert_contains(resp, 'title="The release', count=nb_releases)
-
-    for release in origin_releases:
-        browse_release_url = reverse(
-            "browse-release",
-            url_args={"sha1_git": release["id"]},
-            query_params=query_params,
-        )
-        browse_revision_url = reverse(
-            "browse-revision",
-            url_args={"sha1_git": release["target"]},
-            query_params=query_params,
-        )
-
-        assert_contains(resp, '<a href="%s">' % escape(browse_release_url))
-        assert_contains(resp, '<a href="%s">' % escape(browse_revision_url))
-
-    _check_origin_link(resp, origin_info["url"])
-
-
-@given(
-    new_origin(), visit_dates(),
-)
-def test_origin_branches_pagination_with_alias(
-    client, archive_data, mocker, release, revisions_list, new_origin, visit_dates,
-):
-    """
-    When a snapshot contains a branch or a release alias, pagination links
-    in the branches / releases view should be displayed.
-    """
-    revisions = revisions_list(size=10)
-    mocker.patch("swh.web.browse.snapshot_context.PER_PAGE", len(revisions) / 2)
-    snp_dict = {"branches": {}, "id": hash_to_bytes(random_sha1())}
-    for i in range(len(revisions)):
-        branch = "".join(random.choices(string.ascii_lowercase, k=8))
-        snp_dict["branches"][branch.encode()] = {
-            "target_type": "revision",
-            "target": hash_to_bytes(revisions[i]),
-        }
-    release_name = "".join(random.choices(string.ascii_lowercase, k=8))
-    snp_dict["branches"][b"RELEASE_ALIAS"] = {
-        "target_type": "alias",
-        "target": release_name.encode(),
-    }
-    snp_dict["branches"][release_name.encode()] = {
-        "target_type": "release",
-        "target": hash_to_bytes(release),
-    }
-    archive_data.origin_add([new_origin])
-    archive_data.snapshot_add([Snapshot.from_dict(snp_dict)])
-    visit = archive_data.origin_visit_add(
-        [OriginVisit(origin=new_origin.url, date=visit_dates[0], type="git",)]
-    )[0]
-    visit_status = OriginVisitStatus(
-        origin=new_origin.url,
-        visit=visit.visit,
-        date=now(),
-        status="full",
-        snapshot=snp_dict["id"],
-    )
-    archive_data.origin_visit_status_add([visit_status])
-
-    url = reverse("browse-origin-branches", query_params={"origin_url": new_origin.url})
-
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/branches.html"
-    )
-    assert_contains(resp, '<ul class="pagination')
-
-
 def _check_origin_link(resp, origin_url):
     browse_origin_url = reverse(
         "browse-origin", query_params={"origin_url": origin_url}
@@ -1303,23 +872,6 @@ def _check_origin_link(resp, origin_url):
     assert_contains(resp, f'href="{browse_origin_url}"')
 
 
-def test_pull_request_branches_filtering(client, origin_with_pull_request_branches):
-    origin_url = origin_with_pull_request_branches.url
-    # check no pull request branches are displayed in the Branches / Releases dropdown
-    url = reverse("browse-origin-directory", query_params={"origin_url": origin_url})
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
-    )
-    assert_not_contains(resp, "refs/pull/")
-
-    # check no pull request branches are displayed in the branches view
-    url = reverse("browse-origin-branches", query_params={"origin_url": origin_url})
-    resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/branches.html"
-    )
-    assert_not_contains(resp, "refs/pull/")
-
-
 def test_browse_pull_request_branch(
     client, archive_data, origin_with_pull_request_branches
 ):
